@@ -15,6 +15,7 @@ from natsort.natsort import (
     natsort_keygen,
     natsorted,
     ns,
+    numeric_regex_chooser,
     order_by_index,
     realsorted,
 )
@@ -23,7 +24,7 @@ from natsort.utils import chain_functions
 if float(sys.version[:3]) < 3:
     from natsort.natsort import natcmp
 
-__version__ = "6.0.0"
+__version__ = "6.2.0"
 
 __all__ = [
     "natsort_key",
@@ -41,6 +42,7 @@ __all__ = [
     "as_utf8",
     "ns",
     "chain_functions",
+    "numeric_regex_chooser",
 ]
 
 # Add the ns keys to this namespace for convenience.
